@@ -637,7 +637,7 @@ $printthis
 									#		open( RETBLOCK, ">>$retblock"); # or die;
 									#	}
 									#}
-									say $tee "COUNTREPORT! " . dump([$countreport]);				
+									#say $tee "COUNTREPORT! " . dump([$countreport]);				
 									my $reportdata_ref = $reportdata_ref_ref->[$countreport]; #say $tee "\$reportdata_ref" . dump($reportdata_ref); 
 									my @reportdata = @$reportdata_ref;  #say $tee "\@reportdata" . dump(@reportdata); 
 									
@@ -667,10 +667,10 @@ $printthis
 											say RETLIST "$retfile";
 										}
 										
-										if ( not ( $retfile ~~ @{ $notecases[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] } ) )
+										if ( not ( $retfile ~~ @{ $notecases[ $countcase ][ $countblock ][ $counttool ][ $countinstance ] } ) )
 										{
 											
-											push ( @{ $notecases[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] } , 
+											push ( @{ $notecases[ $countcase ][ $countblock ][ $counttool ][ $countinstance ] } , 
 																				{
 																					retfile => $retfile,
 																					reporttitle => $reporttitle,
@@ -685,27 +685,30 @@ $printthis
 																				} );
 										}
 										
-										say "#Retrieving results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep for tool $tooltype. Instance $countinstance: going to write $retfile.\ ";
-											
-										if ( $themereport eq "temps" ) 
+										unless ( ( $dowhat{inactivateres} eq "y" ) or ( -e $retfile ) )
 										{
-											 retrieve_temperatures_results( $result, $resfile, \@retrdata, $reporttitle, $themereport, $counttheme, $countreport, $retfile ); 
-										}
-										elsif ( $themereport eq "comfort"  ) 
-										{ 
-											retrieve_comfort_results( $result, $resfile, \@retrdata, $reporttitle, $themereport, $counttheme, $countreport, $retfile ); 
-										}
-										elsif ( ( ( $themereport eq "loads" ) or ( $themereport eq "tempsstats"  ) ) )
-										{ 
-											retrieve_stats_results( $result, $resfile, \@retrdata, $reporttitle, $themereport, $counttheme, 
-														$countreport, $retfile, $semaphorego1, $semaphorego2, $semaphorestop1, $semaphorestop2, $textpattern, $afterlines ); 
-										}
-										elsif ( ( $themereport eq "radent" ) or ( $themereport eq "radabs" ) or ( $themereport eq "airtemp" ) or ( $themereport eq "radtemp" ) or ( $themereport eq "restemp" ) )
-										{ 
-											#say $tee "RETRIEVING ADHOC";
-											retrieve_adhoc( $result, $resfile, \@retrdata, $reporttitle, $themereport, $counttheme, 
-														$countreport, $retfile, $semaphorego1, $semaphorego2, $semaphorestop1, $semaphorestop2, $textpattern, $afterlines ); 
-														#$countreport, $retfile, $semaphorego1, $semaphorego2, $semaphorestop1, $semaphorestop2, $textpattern, $afterlines, $adhoclines ); 
+											say "#Retrieving results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep for tool $tooltype. Instance $countinstance: going to write $retfile.\ ";
+												
+											if ( $themereport eq "temps" ) 
+											{
+												 retrieve_temperatures_results( $result, $resfile, \@retrdata, $reporttitle, $themereport, $counttheme, $countreport, $retfile ); 
+											}
+											elsif ( $themereport eq "comfort"  ) 
+											{ 
+												retrieve_comfort_results( $result, $resfile, \@retrdata, $reporttitle, $themereport, $counttheme, $countreport, $retfile ); 
+											}
+											elsif ( ( ( $themereport eq "loads" ) or ( $themereport eq "tempsstats"  ) ) )
+											{ 
+												retrieve_stats_results( $result, $resfile, \@retrdata, $reporttitle, $themereport, $counttheme, 
+															$countreport, $retfile, $semaphorego1, $semaphorego2, $semaphorestop1, $semaphorestop2, $textpattern, $afterlines ); 
+											}
+											elsif ( ( $themereport eq "radent" ) or ( $themereport eq "radabs" ) or ( $themereport eq "airtemp" ) or ( $themereport eq "radtemp" ) or ( $themereport eq "restemp" ) )
+											{ 
+												#say $tee "RETRIEVING ADHOC";
+												retrieve_adhoc( $result, $resfile, \@retrdata, $reporttitle, $themereport, $counttheme, 
+															$countreport, $retfile, $semaphorego1, $semaphorego2, $semaphorestop1, $semaphorestop2, $textpattern, $afterlines ); 
+															#$countreport, $retfile, $semaphorego1, $semaphorego2, $semaphorestop1, $semaphorestop2, $textpattern, $afterlines, $adhoclines ); 
+											}
 										}
 										$countitem++;
 									}
@@ -829,7 +832,7 @@ $printthis
 	close RETBLOCK;
 	#say $tee "INEXIT \@retcases " . dump( @retcases ); 
 	#say $tee "\@retstruct " . dump( @retstruct ); 
-	#say $tee "\@notecases " . dump( @notecases ); 
+	say $tee "\@notecases " . dump( @notecases ); 
 	return ( \@retcases, \@retstruct, \@notecases );
 }	# END SUB RETRIEVE
 
@@ -986,7 +989,7 @@ sub report # This function retrieves the results of interest from the texts file
 			if ( not ( eval ( $skipsim{$counttool} )))
 			{
 				my $tooltype = $dowhat{simtools}{$counttool}; #say $tee "\$tooltype " . dump( $tooltype );
-				#@{ $notecases[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] } = uniq( @{ $notecases[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] }  );
+				#@{ $notecases[ $countcase ][ $countblock ][ $counttool ][ $countinstance ] } = uniq( @{ $notecases[ $countcase ][ $countblock ][ $counttool ][ $countinstance ] }  );
 				#say $tee "\$notecases[ \$countcase ][ \$countblock ][ \$countinstance ][ \$counttool ] } : " . dump( $notecases[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] );
 				
 				#foreach $ret_ref ( sort { $a->{retfile} <=> $b->{retfile} } ( @{ $notecases[ $countcase ][ $countblock ][ $counttool ][ $countinstance ] } ) )
@@ -1066,38 +1069,38 @@ sub report # This function retrieves the results of interest from the texts file
 									chomp( $line ); chomp( $line ); 
 									if ( $foundhit == 0 )
 									{	
-										push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, "$themereport $line " );
+										push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, "$themereport,$line" );
 									}
 									else
 									{
-										push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, " $line " );
+										push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, $line );
 									}
 									$foundhit++;
 								}
 							}
 							else
 							{
+								#print $tee "AFTERLINES ARE DEFINED FOR \$themereport $themereport ";
 								if ( ( $textpattern ne "" ) and ( $line =~ m/^$textpattern/ ) and ( $semaphore1 eq "on" ) and ( $semaphore2 eq "on" ) )
 								{	#print TOFILE "HIT REPORT1! "; #say TOFILE $line;
 									$signalhit++;
 								}
-								#say $tee "DEFINED AFTERLINES FOR \$themereport $themereport";
 								
 								if ( ( $semaphore1 eq "on" ) and ( $semaphore2 eq "on" ) and ( $signalhit > 0 ) )
 								{
-									#print TOFILE "HIT REPORT1! "; #say TOFILE $line;
+									#print TOFILE "WORKING FOR A SIGNALLED HIT "; #say TOFILE $line;
 									if ( not ( ref( $afterlines ) ) )
 									{	#say $tee "NOT REF BUT DEFINED AFTERLINES FOR \$themereport $themereport";
-										if ( ( $afterlines ne "" ) and ( $countli == $afterlines ) )
+										if ( ( $afterlines ne "" ) and ( $countline == ( $afterlines - 1) ) )
 										{	#print TOFILE "HIT REPORT2! "; #say TOFILE $line;
-											chomp( $line ); chomp( $line ); 
-											push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, "$themereport $line " );
+											chomp( $line );
+											push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, "$themereport,$line" );
 											$countli++;
 										}
 									}
 									else
 									{	#say $tee "REF AND DEFINED AFTERLINES FOR \$themereport $themereport";
-										my @afterlins = @$afterlines;  #say $tee "\@lins @lins";
+										my @afterlins = @$afterlines;  #say $tee "\@afterlins " . dump( @afterlins );
 										my @bringer;
 										foreach my $afterlin ( @afterlins )
 										{	#say $tee "FOREACH \$afterlin: $afterlin";
@@ -1107,7 +1110,8 @@ sub report # This function retrieves the results of interest from the texts file
 											}
 											else
 											{
-												my ( $count, $endel ) = split( /-/, $lin );
+												#say $tee "SPLITTING \$afterlin: $afterlin";
+												my ( $count, $endel ) = split( /-/, $afterlin );
 												while ( $count <= $endel )
 												{
 													push ( @bringer, $count );
@@ -1118,17 +1122,17 @@ sub report # This function retrieves the results of interest from the texts file
 											my $countlocal = 0;
 											foreach my $afterl ( @bringer )
 											{
-												#say $tee "THIS CASE IS ABSENT, ISN'T IT? \$themereport: $themereport";
-												if ( $countlin == $afterl )
+												#say $tee "NOW USING \@bringer @bringer";
+												if ( $countline == ( $afterl - 1 ) )
 												{
-													chomp( $line ); chomp( $line ); 
+													chomp( $line );
 													if ( $countlocal == 0 )
 													{
-														push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, "$themereport $line " );
+														push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, "$themereport,$line" );
 													}
 													else
 													{
-														push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, " $line " );
+														push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, $line );
 													}
 												}
 												$counlin++;
@@ -1143,7 +1147,9 @@ sub report # This function retrieves the results of interest from the texts file
 					}
 					else 
 					{ 
-						say $tee "CAN'T FIND NO RES FILE TO OPEN" and die $!; 
+						open ( NOTFOUND, ">>./notfound.txt" ) or die $! ;
+						say NOTFOUND $retfile;
+						#say $tee "CAN'T FIND NO RES FILE $retfile TO OPEN" and die $!; 
 					}
 				}
 			}
@@ -1152,13 +1158,17 @@ sub report # This function retrieves the results of interest from the texts file
 		#say $tee "\@mergestruct: " . dump(@mergestruct); 
 		say $tee "\@{ \$mergestruct[\$countcase][\$countblock][\$countinstance] } : " . dump(@{ $mergestruct[$countcase][$countblock][ $countinstance ] });
 		
-		foreach my $thing ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] } )
+		unless ( $dowhat{inactivateret} eq "y" )
 		{
-			$thing =~ s/\n/ /g ; $thing =~ s/\n/ /g ; $thing =~ s/\r/ /g ; $thing =~ s/\r/ /g ;
-			$thing =~ s/\r\n/ /g; $thing =~ s/\r\n/ /g;
-			print REPFILE $thing;
-		}
-		print REPFILE "\n";
+			
+			foreach my $thing ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] } )
+			{
+				$thing =~ s/\n/ /g ; $thing =~ s/\n/ /g ; $thing =~ s/\r/ /g ; $thing =~ s/\r/ /g ;
+				$thing =~ s/\r\n/ /g; $thing =~ s/\r\n/ /g;
+				print REPFILE $thing;
+				print REPFILE ",";
+			}
+			print REPFILE "\n";
 		
 		#my $lin;
 		#foreach my $thing ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] } )
@@ -1167,7 +1177,8 @@ sub report # This function retrieves the results of interest from the texts file
 		#	$lin = $lin . $thing . " ";
 		#}
 		#push ( @{ $convey[ $countcase ][ $counblock ] }, $lin );
-		say "#Reporting results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance: writing $repfile. ";
+			say "#Reporting results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance: writing $repfile. ";
+		}
 		$countinstance++;
 	}
 	
