@@ -269,7 +269,7 @@ sub sim    # This function launch the simulations in ESP-r
 							push ( @simcases, $resfile );
 							print SIMLIST "$resfile\n";
 								
-							unless ( $preventsim eq "y" )
+							unless ( ( $preventsim eq "y" ) or ( $dowhat{inactivatesim} eq "y" ) )
 							{
 								if ( $simnetwork eq "y" )
 								{
@@ -437,42 +437,55 @@ $printthis
 							$resfile = "$simelt\\$epresroot$resfiletype"; #say TOFILE "dump(\$resfile ): " . dump( $resfile ); 
 						}
 						
-						if (not (-e $simblock ) )
-						{
-							if ( $countblock == 0 )
-							{
-								open( SIMBLOCK, ">>$simblock"); # or die;
-							}
-							else 
-							{
-								open( SIMBLOCK, ">>$simblock"); # or die;
-							}
-						}
 						
-						if (not (-e $retblock ) )
+						unless ( $dowhat{inactivatesim} eq "y" )
 						{
-							if ( $countblock == 0 )
+							
+							if (not ( -e $simblock ) )
 							{
-								open( RETBLOCK, ">>$retblock"); # or die;
+								if ( $countblock == 0 )
+								{
+									open( SIMBLOCK, ">>$simblock"); # or die;
+								}
+								else 
+								{
+									open( SIMBLOCK, ">>$simblock"); # or die;
+								}
 							}
-							else 
+							
+							if (not (-e $retblock ) )
 							{
-								open( RETBLOCK, ">>$retblock"); # or die;
+								if ( $countblock == 0 )
+								{
+									open( RETBLOCK, ">>$retblock"); # or die;
+								}
+								else 
+								{
+									open( RETBLOCK, ">>$retblock"); # or die;
+								}
 							}
 						}
 						
 						push ( @{ $simstruct[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] }, $resfile );
 						push ( @{ $retstruct[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] }, $resfile );
-						print SIMBLOCK "$resfile\n";
+						
+						unless ( $dowhat{inactivatesim} eq "y" )
+						{
+							print SIMBLOCK "$resfile\n";
+						}
 						
 						if ( ( not ( $resfile ~~ @retcases ) ) and ( not ( -e $resfile ) ) )
 						{
 							push ( @simcases, $resfile );
 							push ( @retcases, $resfile );
-							print SIMLIST "$resfile\n";
-							print RETLIST "$resfile\n";
-								
-							unless ( $preventsim eq "y" )
+							
+							unless ( $dowhat{inactivatesim} eq "y" )
+							{
+								print SIMLIST "$resfile\n";
+								print RETLIST "$resfile\n";
+							}
+							
+							unless ( ( $preventsim eq "y" ) or ( $dowhat{inactivatesim} eq "y" ) )
 							{	
 								open ( OLDFILEEPLUS, $epoldpath ) or die( "$!" );
 								my @oldlines = <OLDFILEEPLUS>;
